/**************************************************************/
/* Include name: m4mqr3a.h                                    */
/*                                                            */
/* Description:  Include file for the sample exit used to     */
/*               demonstrate how to embed the Mercator        */
/*               Platform API into a User Exit for the        */
/*               MQSeries MQLink for R/3 (Windows NT) product.*/
/*                                                            */
/*                                                            */
/*                                                            */
/**************************************************************/

#if !defined (THDR_INCLUDED)         /* Check this file is not*/
  #define THDR_INCLUDED              /*   already included    */

/**************************************************************/
/* Define the name of our log queue                           */
/**************************************************************/
#define LOG_QUEUE_NAME "SapLinkLog\0"

/**************************************************************/
/* Internal exit log data structure. This is the information  */
/* we put to our log queue.                                   */
/**************************************************************/
typedef struct tagLogBuffer
{
        MQCHAR4    InOut ;       /* Indicator of the direction    */
                                 /* of the server which invoked   */
                                 /* the exit.                     */
        MQLONG     ProcessId ;   /* The process id of the server  */
                                 /* as returned by the (_)getpid  */
                                 /* system call.                  */
        char       Phase[12] ;   /* The exit call which was       */
                                 /* called.                       */
        MQLONG     Result ;      /* The result of the call to the */
                                 /* exit.                         */
        char       UserData[80] ;/* User-defined data - not used  */
                                 /* in this sample.               */
} LogBuffer ;
typedef LogBuffer MQPOINTER pLogBuffer ;
#define MSG_IN                  "MSGI"
#define MSG_OUT                 "MSGO"
#define MSG_UNK                 "MSGU"
#define FMT_MMAS                "MMAS    "
#define FMT_APPLICATION "MYAPPFMT"

/**************************************************************/
/* Internal exit control structure. This is used to carry     */
/* info. across invocations of the exit.                      */
/**************************************************************/
typedef struct tagTransLog
{
  MQCHAR4    StrucId ;       /* Id for our structure.         */
  MQHCONN    QMgrHandle ;    /* a copy of the connect handle  */
                             /* passed to the exit on the     */
                             /* initialise call.              */
  MQHOBJ     LogQHandle ;    /* The handle for our log queue  */
  MQLONG     Flags ;         /* A flag field for the exit's   */
                             /* internal use.                 */
  MQCHAR32   ExitBuffer ;    /* A copy of the exit buffer     */
                             /* which was passed to the exit  */
                             /* on the initialise call.       */
  MQLONG     Direction ;     /* a copy of the direction       */
                             /* indicator passed to the exit  */
                             /* on the initialise call.       */
  PMQMD      pLogMQMD ;      /* a pointer to the MQMD used    */
                             /* for the log queue.            */
  pLogBuffer pBuffer ;       /* a pointer to the log data     */
                             /* buffer.                       */
  PMQPMO     pLogMQPMO ;     /* pointer to the put message    */
                             /* options structure used for    */
                             /* log queue.                    */
} TransLog ;
typedef TransLog MQPOINTER pTransLog ;
#define TransLog_ID "TLOG"
#define TransLog_ID_ARRAY 'T','L','O','G'
#define TransLog_DEFAULT {TransLog_ID_ARRAY}, \
                             MQHC_UNUSABLE_HCONN, \
                         MQHO_UNUSABLE_HOBJ, \
                         0L, \
                         "", \
                         0L, \
                         NULL, \
                         NULL, \
                                                 NULL

/**************************************************************/
/* Values for Flags field of exit control structure. The      */
/* first three definitions are set by the Execute routine     */
/* when it acquires storage for any of the data. They are     */
/* tested, and reset if necessary, by the Return routine      */
/* and the storage freed if necessary.                        */
/**************************************************************/
#define TRANS_FREE_HEADER     0x00000001L
#define TRANS_FREE_MQMD       0x00000002L
#define TRANS_FREE_MESSAGE    0x00000004L
#define TRANS_STORAGE_MASK    0xffffff00L

/**************************************************************/
/* Internal exit error codes.                                 */
/**************************************************************/
#define TRANS_NOT_DEFAULT     0x00000001L
#define TRANS_NOT_CONNECTED   0x00000002L
#define TRANS_OPEN_ERROR      0x00000004L
#define TRANS_INV_DIRECTION   0x00000008L
#define TRANS_OTHER_ERROR     0x00000080L
#define TRANS_STORAGE_ERROR   0x00000100L

/**************************************************************/
/* Prototypes for internal exit functions.                    */
/**************************************************************/
void MQENTRY transInbound(PSMQEXIT_SETUP pExitSetup,
                          PSMQEXIT_INPUT pExitInput,
                          PSMQEXIT_OUTPUT pExitOutput) ;
void MQENTRY transOutbound(PSMQEXIT_SETUP pExitSetup,
                          PSMQEXIT_INPUT pExitInput,
                          PSMQEXIT_OUTPUT pExitOutput) ;

#endif
/**************************************************************/
/* End of include smqeshd1.h                                  */
/**************************************************************/






